@@ -4,7 +4,6 @@
 @Contact :   g1879@qq.com
 @File    :   common.py
 """
-from abc import abstractmethod
 from html import unescape
 from pathlib import Path
 from re import split as re_SPLIT
@@ -12,69 +11,6 @@ from shutil import rmtree
 from typing import Union
 from zipfile import ZipFile
 
-from lxml.html import HtmlElement
-from selenium.webdriver.remote.webelement import WebElement
-
-
-class DrissionElement(object):
-    """SessionElement和DriverElement的基类"""
-
-    def __init__(self, ele: Union[WebElement, HtmlElement], page=None):
-        self._inner_ele = ele
-        self.page = page
-
-    @property
-    def inner_ele(self) -> Union[WebElement, HtmlElement]:
-        return self._inner_ele
-
-    @property
-    def is_valid(self):
-        return True
-
-    # @property
-    # def text(self):
-    #     return
-
-    @property
-    def html(self):
-        return
-
-    @property
-    def tag(self):
-        return
-
-    @property
-    def parent(self):
-        return
-
-    @property
-    def next(self):
-        return
-
-    @property
-    def prev(self):
-        return
-
-    # @property
-    # def css_path(self):
-    #     return
-    #
-    # @property
-    # def xpath(self):
-    #     return
-
-    @abstractmethod
-    def ele(self, loc: Union[tuple, str], mode: str = None):
-        pass
-
-    @abstractmethod
-    def eles(self, loc: Union[tuple, str]):
-        pass
-
-    # @abstractmethod
-    # def attr(self, attr: str):
-    #     pass
-
 
 def str_to_loc(loc: str) -> tuple:
     """处理元素查找语句                                                                    \n
@@ -332,7 +268,7 @@ def get_exe_path_from_port(port: Union[str, int]) -> Union[str, None]:
     while not process and perf_counter() - t < 10:
         process = popen(f'netstat -ano |findstr {port}').read().split('\n')[0]
 
-    processid = process[process.rfind(' ') + 1:]
+    processid = process.split(' ')[-1]
 
     if not processid:
         return
