@@ -4,9 +4,9 @@
 @Contact :   g1879@qq.com
 @File    :   driver_element.py
 """
-import re
 from pathlib import Path
-from time import sleep
+from re import sub
+from time import sleep, time
 from typing import Union, List, Any, Tuple
 
 from selenium.common.exceptions import TimeoutException, JavascriptException, InvalidElementStateException
@@ -15,7 +15,8 @@ from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support import expected_conditions as ec
 from selenium.webdriver.support.wait import WebDriverWait
 
-from .common import DrissionElement, str_to_loc, get_available_file_name, translate_loc, format_html
+from .base import DrissionElement
+from .common import str_to_loc, get_available_file_name, translate_loc, format_html
 
 
 class DriverElement(DrissionElement):
@@ -33,16 +34,21 @@ class DriverElement(DrissionElement):
                  loc_or_str: Union[Tuple[str, str], str],
                  mode: str = 'single',
                  timeout: float = None):
-        """实现查找元素的简化写法                                     \n
+        """在内部查找元素                                            \n
         例：ele2 = ele1('@id=ele_id')                               \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param mode: 'single' 或 'all'，对应查找一个或全部
         :param timeout: 超时时间
         :return: DriverElement对象
         """
-        return self.ele(loc_or_str, mode, timeout)
+        return super().__call__(loc_or_str, mode, timeout)
+
+    # -----------------共有属性和方法-------------------
+    @property
+    def tag(self) -> str:
+        """返回元素类型"""
+        return self._inner_ele.tag_name.lower()
 
-    # -----------------共有属性-------------------
     @property
     def html(self) -> str:
         """返回元素outerHTML文本"""
@@ -53,11 +59,6 @@ class DriverElement(DrissionElement):
         """返回元素innerHTML文本"""
         return self.attr('innerHTML')
 
-    @property
-    def tag(self) -> str:
-        """返回元素类型"""
-        return self._inner_ele.tag_name.lower()
-
     @property
     def attrs(self) -> dict:
         """返回元素所有属性及值"""
@@ -82,8 +83,8 @@ class DriverElement(DrissionElement):
         """返回元素内所有文本"""
         # return format_html(self.inner_ele.get_attribute('innerText'), False)
         re_str = self.inner_ele.get_attribute('innerText')
-        re_str = re.sub(r'\n{2,}', '\n', re_str)
-        re_str = re.sub(r' {2,}', ' ', re_str)
+        re_str = sub(r'\n{2,}', '\n', re_str)
+        re_str = sub(r' {2,}', ' ', re_str)
 
         return format_html(re_str.strip('\n '), False)
 
@@ -92,41 +93,109 @@ class DriverElement(DrissionElement):
         """返回未格式化处理的元素内文本"""
         return self.inner_ele.get_attribute('innerText')
 
-    @property
-    def link(self) -> str:
-        """返回href或src绝对url"""
-        return self.attr('href') or self.attr('src')
+    def parents(self, num: int = 1):
+        """返回上面第num级父元素              \n
+        :param num: 第几级父元素
+        :return: DriverElement对象
+        """
+        loc = 'xpath', f'.{"/.." * num}'
+        return self.ele(loc, timeout=0)
 
-    @property
-    def css_path(self) -> str:
-        """返回当前元素的css路径"""
-        return self._get_ele_path('css')
+    def attr(self, attr: str) -> str:
+        """获取attribute属性值            \n
+        :param attr: 属性名
+        :return: 属性值文本
+        """
+        # attr = 'innerText' if attr == 'text' else attr
+        if attr in ('text', 'innerText'):
+            return self.text
 
-    @property
-    def xpath(self) -> str:
-        return self._get_ele_path('xpath')
+        return format_html(self.inner_ele.get_attribute(attr))
 
-    @property
-    def parent(self):
-        """返回父级元素"""
-        return self.parents()
+    def ele(self,
+            loc_or_str: Union[Tuple[str, str], str],
+            mode: str = None,
+            timeout: float = None):
+        """返回当前元素下级符合条件的子元素、属性或节点文本，默认返回第一个                                      \n
+        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :param mode: 'single' 或 'all'，对应查找一个或全部
+        :param timeout: 查找元素超时时间
+        :return: DriverElement对象
+        """
+        if isinstance(loc_or_str, (str, tuple)):
+            if isinstance(loc_or_str, str):
+                loc_or_str = str_to_loc(loc_or_str)
+            else:
+                if len(loc_or_str) != 2:
+                    raise ValueError("Len of loc_or_str must be 2 when it's a tuple.")
+                loc_or_str = translate_loc(loc_or_str)
+        else:
+            raise ValueError('Argument loc_or_str can only be tuple or str.')
 
-    @property
-    def next(self):
-        """返回后一个兄弟元素"""
-        return self._get_brother(1, 'ele', 'next')
+        loc_str = loc_or_str[1]
 
-    @property
-    def prev(self):
-        """返回前一个兄弟元素"""
-        return self._get_brother(1, 'ele', 'prev')
+        if loc_or_str[0] == 'xpath' and loc_or_str[1].lstrip().startswith('/'):
+            loc_str = f'.{loc_str}'
 
-    @property
-    def comments(self) -> list:
-        """返回元素注释文本组成的列表"""
-        return self.eles('xpath:.//comment()')
+        if loc_or_str[0] == 'css selector' and loc_or_str[1].lstrip().startswith('>'):
+            loc_str = f'{self.css_path}{loc_or_str[1]}'
 
-    # -----------------driver独占属性-------------------
+        loc_or_str = loc_or_str[0], loc_str
+
+        return execute_driver_find(self, loc_or_str, mode, timeout)
+
+    def eles(self,
+             loc_or_str: Union[Tuple[str, str], str],
+             timeout: float = None):
+        """返回当前元素下级所有符合条件的子元素、属性或节点文本                                                   \n
+        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
+        :param timeout: 查找元素超时时间
+        :return: DriverElement对象组成的列表
+        """
+        return self.ele(loc_or_str, mode='all', timeout=timeout)
+
+    def _get_ele_path(self, mode) -> str:
+        """返获取css路径或xpath路径"""
+        if mode == 'xpath':
+            txt1 = 'var tag = el.nodeName.toLowerCase();'
+            # txt2 = '''return '//' + tag + '[@id="' + el.id + '"]'  + path;'''
+            txt3 = ''' && sib.nodeName.toLowerCase()==tag'''
+            txt4 = '''
+            if(nth>1){path = '/' + tag + '[' + nth + ']' + path;}
+                    else{path = '/' + tag + path;}'''
+            txt5 = '''return path;'''
+
+        elif mode == 'css':
+            txt1 = ''
+            # txt2 = '''return '#' + el.id + path;'''
+            txt3 = ''
+            txt4 = '''path = '>' + ":nth-child(" + nth + ")" + path;'''
+            txt5 = '''return path.substr(1);'''
+
+        else:
+            raise ValueError(f"Argument mode can only be 'xpath' or 'css', not '{mode}'.")
+
+        js = '''
+        function e(el) {
+            if (!(el instanceof Element)) return;
+            var path = '';
+            while (el.nodeType === Node.ELEMENT_NODE) {
+                ''' + txt1 + '''
+                    var sib = el, nth = 0;
+                    while (sib) {
+                        if(sib.nodeType === Node.ELEMENT_NODE''' + txt3 + '''){nth += 1;}
+                        sib = sib.previousSibling;
+                    }
+                    ''' + txt4 + '''
+                el = el.parentNode;
+            }
+            ''' + txt5 + '''
+        }
+        return e(arguments[0]);
+        '''
+        return self.run_script(js)
+
+    # -----------------driver独有属性和方法-------------------
     @property
     def size(self) -> dict:
         """返回元素宽和高"""
@@ -171,160 +240,17 @@ class DriverElement(DrissionElement):
 
         return self._select
 
-    # -----------------共有函数-------------------
-
-    def texts(self, text_node_only: bool = False) -> list:
-        """返回元素内所有直接子节点的文本，包括元素和文本节点   \n
-        :param text_node_only: 是否只返回文本节点
-        :return: 文本列表
+    def wait_ele(self,
+                 loc_or_ele: Union[str, tuple, DrissionElement, WebElement],
+                 mode: str,
+                 timeout: float = None) -> bool:
+        """等待子元素从dom删除、显示、隐藏                             \n
+        :param loc_or_ele: 可以是元素、查询字符串、loc元组
+        :param mode: 等待方式，可选：'del', 'display', 'hidden'
+        :param timeout: 等待超时时间
+        :return: 等待是否成功
         """
-        if text_node_only:
-            texts = self.eles('xpath:/text()')
-        else:
-            texts = [x if isinstance(x, str) else x.text for x in self.eles('xpath:./text() | *')]
-
-        return [x.strip(' ') for x in texts if x and x.replace('\n', '').replace('\t', '').replace(' ', '') != '']
-
-    def parents(self, num: int = 1):
-        """返回上面第num级父元素              \n
-        :param num: 第几级父元素
-        :return: DriverElement对象
-        """
-        loc = 'xpath', f'.{"/.." * num}'
-        return self.ele(loc, timeout=0)
-
-    def nexts(self, num: int = 1, mode: str = 'ele'):
-        """返回后面第num个兄弟元素或节点文本                                   \n
-        :param num: 后面第几个兄弟元素或节点
-        :param mode: 'ele', 'node' 或 'text'，匹配元素、节点、或文本节点
-        :return: DriverElement对象或字符串
-        """
-        return self._get_brother(num, mode, 'next')
-
-    def prevs(self, num: int = 1, mode: str = 'ele'):
-        """返回前面第num个兄弟元素或节点文本                                   \n
-        :param num: 前面第几个兄弟元素或节点
-        :param mode: 'ele', 'node' 或 'text'，匹配元素、节点、或文本节点
-        :return: DriverElement对象或字符串
-        """
-        return self._get_brother(num, mode, 'prev')
-
-    def attr(self, attr: str) -> str:
-        """获取属性值            \n
-        :param attr: 属性名
-        :return: 属性值文本
-        """
-        # attr = 'innerText' if attr == 'text' else attr
-        if attr in ('text', 'innerText'):
-            return self.text
-
-        return format_html(self.inner_ele.get_attribute(attr))
-
-    def ele(self,
-            loc_or_str: Union[Tuple[str, str], str],
-            mode: str = None,
-            timeout: float = None):
-        """返回当前元素下级符合条件的子元素、属性或节点文本，默认返回第一个                                      \n
-        示例：                                                                                            \n
-        - 用loc元组查找：                                                                                 \n
-            ele.ele((By.CLASS_NAME, 'ele_class'))       - 返回第一个class为ele_class的子元素               \n
-        - 用查询字符串查找：                                                                               \n
-            查找方式：属性、tag name和属性、文本、xpath、css selector、id、class                              \n
-            @表示属性，.表示class，#表示id，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串            \n
-            ele.ele('.ele_class')                       - 返回第一个 class 为 ele_class 的子元素            \n
-            ele.ele('.:ele_class')                      - 返回第一个 class 中含有 ele_class 的子元素         \n
-            ele.ele('#ele_id')                          - 返回第一个 id 为 ele_id 的子元素                   \n
-            ele.ele('#:ele_id')                         - 返回第一个 id 中含有 ele_id 的子元素               \n
-            ele.ele('@class:ele_class')                 - 返回第一个class含有ele_class的子元素               \n
-            ele.ele('@name=ele_name')                   - 返回第一个name等于ele_name的子元素                 \n
-            ele.ele('@placeholder')                     - 返回第一个带placeholder属性的子元素                \n
-            ele.ele('tag:p')                            - 返回第一个<p>子元素                               \n
-            ele.ele('tag:div@class:ele_class')          - 返回第一个class含有ele_class的div子元素            \n
-            ele.ele('tag:div@class=ele_class')          - 返回第一个class等于ele_class的div子元素            \n
-            ele.ele('tag:div@text():some_text')         - 返回第一个文本含有some_text的div子元素              \n
-            ele.ele('tag:div@text()=some_text')         - 返回第一个文本等于some_text的div子元素              \n
-            ele.ele('text:some_text')                   - 返回第一个文本含有some_text的子元素                 \n
-            ele.ele('some_text')                        - 返回第一个文本含有some_text的子元素（等价于上一行）   \n
-            ele.ele('text=some_text')                   - 返回第一个文本等于some_text的子元素                 \n
-            ele.ele('xpath://div[@class="ele_class"]')  - 返回第一个符合xpath的子元素                         \n
-            ele.ele('css:div.ele_class')                - 返回第一个符合css selector的子元素                  \n
-        - 查询字符串还有最精简模式，用x代替xpath、c代替css、t代替tag、tx代替text：                                \n
-            ele.ele('x://div[@class="ele_class"]')      - 等同于 ele.ele('xpath://div[@class="ele_class"]') \n
-            ele.ele('c:div.ele_class')                  - 等同于 ele.ele('css:div.ele_class')               \n
-            ele.ele('t:div')                            - 等同于 ele.ele('tag:div')                         \n
-            ele.ele('t:div@tx()=some_text')             - 等同于 ele.ele('tag:div@text()=some_text')        \n
-            ele.ele('tx:some_text')                     - 等同于 ele.ele('text:some_text')                  \n
-            ele.ele('tx=some_text')                     - 等同于 ele.ele('text=some_text')
-        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param mode: 'single' 或 'all'，对应查找一个或全部
-        :param timeout: 查找元素超时时间
-        :return: DriverElement对象
-        """
-        if isinstance(loc_or_str, (str, tuple)):
-            if isinstance(loc_or_str, str):
-                loc_or_str = str_to_loc(loc_or_str)
-            else:
-                if len(loc_or_str) != 2:
-                    raise ValueError("Len of loc_or_str must be 2 when it's a tuple.")
-
-                loc_or_str = translate_loc(loc_or_str)
-
-        else:
-            raise ValueError('Argument loc_or_str can only be tuple or str.')
-
-        loc_str = loc_or_str[1]
-
-        if loc_or_str[0] == 'xpath' and loc_or_str[1].lstrip().startswith('/'):
-            loc_str = f'.{loc_str}'
-
-        if loc_or_str[0] == 'css selector' and loc_or_str[1].lstrip().startswith('>'):
-            loc_str = f'{self.css_path}{loc_or_str[1]}'
-
-        loc_or_str = loc_or_str[0], loc_str
-
-        return execute_driver_find(self, loc_or_str, mode, timeout)
-
-    def eles(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None):
-        """返回当前元素下级所有符合条件的子元素、属性或节点文本                                                   \n
-        示例：                                                                                              \n
-        - 用loc元组查找：                                                                                    \n
-            ele.eles((By.CLASS_NAME, 'ele_class'))       - 返回所有class为ele_class的子元素                   \n
-        - 用查询字符串查找：                                                                                  \n
-            查找方式：属性、tag name和属性、文本、xpath、css selector、id、class                                \n
-            @表示属性，.表示class，#表示id，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串              \n
-            ele.eles('.ele_class')                       - 返回所有 class 为 ele_class 的子元素               \n
-            ele.eles('.:ele_class')                      - 返回所有 class 中含有 ele_class 的子元素            \n
-            ele.eles('#ele_id')                          - 返回所有 id 为 ele_id 的子元素                      \n
-            ele.eles('#:ele_id')                         - 返回所有 id 中含有 ele_id 的子元素                  \n
-            ele.eles('@class:ele_class')                 - 返回所有class含有ele_class的子元素                  \n
-            ele.eles('@name=ele_name')                   - 返回所有name等于ele_name的子元素                    \n
-            ele.eles('@placeholder')                     - 返回所有带placeholder属性的子元素                   \n
-            ele.eles('tag:p')                            - 返回所有<p>子元素                                  \n
-            ele.eles('tag:div@class:ele_class')          - 返回所有class含有ele_class的div子元素               \n
-            ele.eles('tag:div@class=ele_class')          - 返回所有class等于ele_class的div子元素               \n
-            ele.eles('tag:div@text():some_text')         - 返回所有文本含有some_text的div子元素                 \n
-            ele.eles('tag:div@text()=some_text')         - 返回所有文本等于some_text的div子元素                 \n
-            ele.eles('text:some_text')                   - 返回所有文本含有some_text的子元素                    \n
-            ele.eles('some_text')                        - 返回所有文本含有some_text的子元素（等价于上一行）      \n
-            ele.eles('text=some_text')                   - 返回所有文本等于some_text的子元素                    \n
-            ele.eles('xpath://div[@class="ele_class"]')  - 返回所有符合xpath的子元素                            \n
-            ele.eles('css:div.ele_class')                - 返回所有符合css selector的子元素                     \n
-        - 查询字符串还有最精简模式，用x代替xpath、c代替css、t代替tag、tx代替text：                                  \n
-            ele.eles('x://div[@class="ele_class"]')      - 等同于 ele.eles('xpath://div[@class="ele_class"]') \n
-            ele.eles('c:div.ele_class')                  - 等同于 ele.eles('css:div.ele_class')               \n
-            ele.eles('t:div')                            - 等同于 ele.eles('tag:div')                         \n
-            ele.eles('t:div@tx()=some_text')             - 等同于 ele.eles('tag:div@text()=some_text')        \n
-            ele.eles('tx:some_text')                     - 等同于 ele.eles('text:some_text')                  \n
-            ele.eles('tx=some_text')                     - 等同于 ele.eles('text=some_text')
-        :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
-        :param timeout: 查找元素超时时间
-        :return: DriverElement对象组成的列表
-        """
-        return self.ele(loc_or_str, mode='all', timeout=timeout)
-
-    # -----------------driver独占函数-------------------
+        return _wait_ele(self, loc_or_ele, mode, timeout)
 
     def get_style_property(self, style: str, pseudo_ele: str = '') -> str:
         """返回元素样式属性值
@@ -385,22 +311,53 @@ class DriverElement(DrissionElement):
             from selenium.webdriver import ActionChains
             ActionChains(self.page.driver).move_to_element_with_offset(self.inner_ele, x, y).click().perform()
 
-    def input(self, value: Union[str, tuple], clear: bool = True) -> bool:
-        """输入文本或组合键                          \n
-        :param value: 文本值或按键组合
-        :param clear: 输入前是否清空文本框
-        :return: 是否输入成功
+    def r_click(self) -> None:
+        """右键单击"""
+        from selenium.webdriver import ActionChains
+        ActionChains(self.page.driver).context_click(self.inner_ele).perform()
+
+    def r_click_at(self, x: Union[int, str] = None, y: Union[int, str] = None) -> None:
+        """带偏移量右键单击本元素，相对于左上角坐标。不传入x或y值时点击元素中点    \n
+        :param x: 相对元素左上角坐标的x轴偏移量
+        :param y: 相对元素左上角坐标的y轴偏移量
+        :return: None
         """
-        try:
+        x = int(x) if x is not None else self.size['width'] // 2
+        y = int(y) if y is not None else self.size['height'] // 2
+        from selenium.webdriver import ActionChains
+        ActionChains(self.page.driver).move_to_element_with_offset(self.inner_ele, x, y).context_click().perform()
+
+    def input(self, vals: Union[str, tuple], clear: bool = True) -> None:
+        """输入文本或组合键，可用于所有场合          \n
+        :param vals: 文本值或按键组合
+        :param clear: 输入前是否清空文本框
+        :return: None
+        """
+        if clear:
+            self.clear()
+
+        self.inner_ele.send_keys(*vals)
+
+    def input_txt(self, txt: Union[str, tuple], clear: bool = True) -> None:
+        """专门用于输入文本框，解决文本框有时输入失效的问题       \n
+        :param txt: 文本值
+        :param clear: 输入前是否清空文本框
+        :return: None
+        """
+        enter = '\n' if txt.endswith('\n') else None
+        full_txt = txt if clear else f'{self.attr("value")}{txt}'
+        full_txt = full_txt.rstrip('\n')
+        from time import perf_counter
+
+        t1 = perf_counter()
+        while self.attr('value') != full_txt and perf_counter() - t1 > self.page.timeout:
             if clear:
                 self.clear()
 
-            self.inner_ele.send_keys(*value)
-            return True
+            self.inner_ele.send_keys(txt)
 
-        except Exception as e:
-            print(e)
-            return False
+        if enter:
+            self.inner_ele.send_keys(enter)
 
     def run_script(self, script: str, *args) -> Any:
         """执行js代码，传入自己为第一个参数  \n
@@ -416,8 +373,7 @@ class DriverElement(DrissionElement):
 
     def clear(self) -> None:
         """清空元素文本"""
-        self.run_script("arguments[0].value=''")
-        # self.inner_ele.clear()
+        self.inner_ele.clear()
 
     def is_selected(self) -> bool:
         """是否选中"""
@@ -463,7 +419,14 @@ class DriverElement(DrissionElement):
 
         return img_path
 
-    def set_property(self, prop: str, value: str) -> bool:
+    def prop(self, prop: str) -> str:
+        """获取property属性值            \n
+        :param prop: 属性名
+        :return: 属性值文本
+        """
+        return format_html(self.inner_ele.get_property(prop))
+
+    def set_prop(self, prop: str, value: str) -> bool:
         """设置元素property属性          \n
         :param prop: 属性名
         :param value: 属性值
@@ -562,85 +525,6 @@ class DriverElement(DrissionElement):
         from selenium.webdriver import ActionChains
         ActionChains(self.page.driver).move_to_element(self.inner_ele).perform()
 
-    # -----------------私有函数-------------------
-    def _get_ele_path(self, mode) -> str:
-        """返获取css路径或xpath路径"""
-        if mode == 'xpath':
-            txt1 = 'var tag = el.nodeName.toLowerCase();'
-            # txt2 = '''return '//' + tag + '[@id="' + el.id + '"]'  + path;'''
-            txt3 = ''' && sib.nodeName.toLowerCase()==tag'''
-            txt4 = '''
-            if(nth>1){path = '/' + tag + '[' + nth + ']' + path;}
-                    else{path = '/' + tag + path;}'''
-            txt5 = '''return path;'''
-
-        elif mode == 'css':
-            txt1 = ''
-            # txt2 = '''return '#' + el.id + path;'''
-            txt3 = ''
-            txt4 = '''path = '>' + ":nth-child(" + nth + ")" + path;'''
-            txt5 = '''return path.substr(1);'''
-
-        else:
-            raise ValueError(f"Argument mode can only be 'xpath' or 'css', not '{mode}'.")
-
-        js = '''
-        function e(el) {
-            if (!(el instanceof Element)) return;
-            var path = '';
-            while (el.nodeType === Node.ELEMENT_NODE) {
-                ''' + txt1 + '''
-                    var sib = el, nth = 0;
-                    while (sib) {
-                        if(sib.nodeType === Node.ELEMENT_NODE''' + txt3 + '''){nth += 1;}
-                        sib = sib.previousSibling;
-                    }
-                    ''' + txt4 + '''
-                el = el.parentNode;
-            }
-            ''' + txt5 + '''
-        }
-        return e(arguments[0]);
-        '''
-        return self.run_script(js)
-
-    def _get_brother(self, num: int = 1, mode: str = 'ele', direction: str = 'next'):
-        """返回前面第num个兄弟节点或元素        \n
-        :param num: 前面第几个兄弟节点或元素
-        :param mode: 'ele', 'node' 或 'text'，匹配元素、节点、或文本节点
-        :param direction: 'next' 或 'prev'，查找的方向
-        :return: DriverElement对象或字符串
-        """
-        # 查找节点的类型
-        if mode == 'ele':
-            node_txt = '*'
-        elif mode == 'node':
-            node_txt = 'node()'
-        elif mode == 'text':
-            node_txt = 'text()'
-        else:
-            raise ValueError(f"Argument mode can only be 'node' ,'ele' or 'text', not '{mode}'.")
-
-        # 查找节点的方向
-        if direction == 'next':
-            direction_txt = 'following'
-        elif direction == 'prev':
-            direction_txt = 'preceding'
-        else:
-            raise ValueError(f"Argument direction can only be 'next' or 'prev', not '{direction}'.")
-
-        timeout = 0 if direction == 'prev' else .5
-
-        # 获取节点
-        ele_or_node = self.ele(f'xpath:./{direction_txt}-sibling::{node_txt}[{num}]', timeout=timeout)
-
-        # 跳过元素间的换行符
-        while isinstance(ele_or_node, str) and ele_or_node.replace('\n', '').replace('\t', '').replace(' ', '') == '':
-            num += 1
-            ele_or_node = self.ele(f'xpath:./{direction_txt}-sibling::{node_txt}[{num}]', timeout=timeout)
-
-        return ele_or_node
-
 
 def execute_driver_find(page_or_ele,
                         loc: Tuple[str, str],
@@ -669,8 +553,8 @@ def execute_driver_find(page_or_ele,
     if timeout is not None and timeout != page.timeout:
         wait = WebDriverWait(driver, timeout=timeout)
     else:
-        page.wait._driver = driver
-        wait = page.wait
+        page.wait_object._driver = driver
+        wait = page.wait_object
 
     try:
         # 使用xpath查找
@@ -942,3 +826,80 @@ class Select(object):
 
         for i in self.options:
             i.click()
+
+
+def _wait_ele(page_or_ele,
+              loc_or_ele: Union[str, tuple, DriverElement, WebElement],
+              mode: str,
+              timeout: float = None) -> bool:
+    """等待元素从dom删除、显示、隐藏                             \n
+    :param page_or_ele: 要等待子元素的页面或元素
+    :param loc_or_ele: 可以是元素、查询字符串、loc元组
+    :param mode: 等待方式，可选：'del', 'display', 'hidden'
+    :param timeout: 等待超时时间
+    :return: 等待是否成功
+    """
+    if mode.lower() not in ('del', 'display', 'hidden'):
+        raise ValueError('Argument mode can only be "del", "display", "hidden"')
+
+    if isinstance(page_or_ele, DrissionElement):
+        page = page_or_ele.page
+        ele_or_driver = page_or_ele.inner_ele
+    else:
+        page = page_or_ele
+        ele_or_driver = page_or_ele.driver
+
+    timeout = timeout or page.timeout
+    is_ele = False
+
+    if isinstance(loc_or_ele, DriverElement):
+        loc_or_ele = loc_or_ele.inner_ele
+        is_ele = True
+
+    elif isinstance(loc_or_ele, WebElement):
+        is_ele = True
+
+    elif isinstance(loc_or_ele, str):
+        loc_or_ele = str_to_loc(loc_or_ele)
+
+    elif isinstance(loc_or_ele, tuple):
+        pass
+
+    else:
+        raise TypeError('The type of loc_or_ele can only be str, tuple, DriverElement, WebElement')
+
+    # 当传入参数是元素对象时
+    if is_ele:
+        end_time = time() + timeout
+
+        while time() < end_time:
+            if mode == 'del':
+                try:
+                    loc_or_ele.is_enabled()
+                except:
+                    return True
+
+            elif mode == 'display' and loc_or_ele.is_displayed():
+                return True
+
+            elif mode == 'hidden' and not loc_or_ele.is_displayed():
+                return True
+
+        return False
+
+    # 当传入参数是控制字符串或元组时
+    else:
+        try:
+            if mode == 'del':
+                WebDriverWait(ele_or_driver, timeout).until_not(ec.presence_of_element_located(loc_or_ele))
+
+            elif mode == 'display':
+                WebDriverWait(ele_or_driver, timeout).until(ec.visibility_of_element_located(loc_or_ele))
+
+            elif mode == 'hidden':
+                WebDriverWait(ele_or_driver, timeout).until_not(ec.visibility_of_element_located(loc_or_ele))
+
+            return True
+
+        except:
+            return False
